'use strict';

var fs = require('fs');
var path = require('path');
var funcs = require('./allfunctions');

var generated = './';
var func_generated_table = '## Methods \n\n| Method Name | Category | Description | Return Type |\n| ------------| ------------| ------------| ------------|';

var header = '![](https://github.com/theIYD/functions.js/blob/master/media/functionsjs.png)\n\n# functions.js\n\n> **functions.js** is a hub of various functions or methods which act differently according to their functionality.\n\n - Please feel free to contribute, read the ![contributions guide](https://github.com/theIYD/functions.js/blob/master/CONTRIBUTING.md).\n - The code is written in ES6.\n\n';

func_generated_table += '\n';
try {
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {

        for (var _iterator = funcs[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
            var func = _step.value;

            func_generated_table += '|' + func.title + ' |' + func.topic + ' |' + func.description + ' |' + func.return_type + ' |\n';
        }
    } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
    } finally {
        try {
            if (!_iteratorNormalCompletion && _iterator.return) {
                _iterator.return();
            }
        } finally {
            if (_didIteratorError) {
                throw _iteratorError;
            }
        }
    }
} catch (err) {
    throw new Error('Error : ' + err);
}

func_generated_table += '\n';

var marked = '```';

var jscode = 'const func = require(\'functions.js\');\n\nconsole.log(func.MathFunc.Pythagoras.pythagorasDistance(3,4));\n//returns \'5\'\n\nconsole.log(func.StringValidate.stringfunc.isItHexColor(\'#fc3\'));\n//returns \'true\'\n' + marked + '\n';

var install = '## Install\n\nThe project is up on ![npm]() and can be used in a project by: \n\n' + marked + '\nnpm install --save functions.js\n\n' + marked + '\n';

var usage = '## Usage\n\nBelow is an example on how to use the library into your projects.\n\n' + marked + 'js\n\n' + jscode;

var license = '\n## License\n The project is licensed under ![MIT](https://github.com/theIYD/functions.js/blob/master/LICENSE)';
output = header + install + usage + func_generated_table + license;

var contributing_guide_header = '# Contributing\n To this project, you can contribute by sending pull requests for new functions that might solve some problem or reduce the complexity of a problem.\n';

var contributing_guide_content = '\n### Guide for new functions\n \n-  The function should be created in <code>src/{category}/functions/{filename.js}</code> Add the particular function entry to category.js.\n\n- The function should be explained above the function declaration itself with the help of multi-line comments. \n\n- The code written should be in **ES6** only.\n\n- Be sure to test the function before making a pull request. \n\n';

fs.writeFileSync(path.join(generated, 'README.md'), output, function (err) {
    console.log(err);
});

contributing_guide = contributing_guide_header + contributing_guide_content;
try {
    fs.writeFileSync(path.join(generated, 'CONTRIBUTING.md'), contributing_guide, function (err) {
        console.log(err);
    });
} catch (err) {
    throw new Error(err);
}